version 10
*** stata file for exchange paper ***
clear
set scheme s2mono
set matsize 300
set more off

*cd ~/CloudStation/projects/exchange/stata/
*cd "/Users/zhenzeng/Dropbox/shared/shared exchange/stata/"
cd "/Users/cschwart/Dropbox/shared/shared exchange/stata/"


capture log close
log using loglinear20160320.log, replace

use zz_exchange_psid13.dta, clear 

*Norm weights
sum fwgt
replace fwgt = fwgt / r(mean) 

*Drop if fwgt = 0
drop if fwgt == 0 


renvars hdied wfied hdpaed hdmaed wfpaed wfmaed  \ eduy_h eduy_w hfe hme wfe wme
egen x = rownonmiss(hfe hme wme wfe eduy_h eduy_w)
tab x
keep if x == 6
sum eduy_h eduy_w hfe hme wfe wme
tab eduy_h eduy_w

***Sample size***
display _N
local nobs = _N
display `nobs'

**** checking edu homogamy ****
gen e_dif = eduy_h - eduy_w
tab e_dif [aw=fwgt]
tab e_dif 

recode eduy_h (0/11=1) (12=2) (13/15=3) (16/max=4), gen(he)
recode eduy_w (0/11=1) (12=2) (13/15=3) (16/max=4), gen(we)
replace e_dif = he - we
tab e_dif [aw=fwgt]

drop e_dif he we

recode hfe hme wfe wme (5=4) (6=5) (7=6) (8=7) 
recode eduy_h (0/5=1) (6/8=2) (9/11=3) (12=4) (13/15=5) (16=6) (17/max=7), gen(he)
recode eduy_w (0/5=1) (6/8=2) (9/11=3) (12=4) (13/15=5) (16=6) (17/max=7), gen(we)
recode hfe (1=3) (2=7) (3=10) (4=12) (5=14) (6=16) (7=18), gen(eduy_hf)
recode hme (1=3) (2=7) (3=10) (4=12) (5=14) (6=16) (7=18), gen(eduy_hm)
recode wfe (1=3) (2=7) (3=10) (4=12) (5=14) (6=16) (7=18), gen(eduy_wf)
recode wme (1=3) (2=7) (3=10) (4=12) (5=14) (6=16) (7=18), gen(eduy_wm)

lab def edu 1 "0-5" 2 "6-8" 3 "9-11" 4 "12" 5 "13-15" 6 "16" 7 "17+"
lab val hfe edu
lab val hme edu
lab val wfe edu
lab val wme edu
lab val he edu
lab val we edu

*check var creation
tab eduy_h he
tab eduy_w we
tab hfe eduy_hf
tab hme eduy_hm
tab wfe eduy_wf
tab wme eduy_wm


**** create origin measures ****
*** try 4 measures, measure 1 is used in the paper ***
* ho1 wo1 = sum of parents' years of schooling 
gen ho1 = eduy_hf + eduy_hm
gen wo1 = eduy_wf + eduy_wm

tab ho1 [aw=fwgt]
recode ho1 wo1 (6/14=1) (15/17=2) (18/21=3) (22/23=4) (24=5) (25/28=6) (30/36=7)
tab ho1 wo1 [aw=fwgt]

* ho2 = father's occe score 
egen occe_hf = mean(eduy_hf), by(hdpaoc) //17.5% unknown//
xtile ho2 = occe_hf, nq(7) 
tab ho2 wo1 [aw=fwgt]
table ho2 wo1 [aw=fwgt], c(mean he mean we)

* ho3 = father's ranked occupational category
bysort hdpaoc: sum(occe_hf)
recode hdpaoc (7 8=1) (6=2) (5=3) (9 =4) (3 4 =5) (2=6) (1=7), gen(ho3) 
tab ho3 wo1 [aw=fwgt]

* ho4 = sum of father's occe score and m_edu zscores
*package zscore from http://www.stata.com/users/sdriver
zscore occe_hf eduy_hm, stub(z_)
xtile ho4 = z_occe_hf + z_eduy_hm, nq(7)
tab ho4 wo1 [aw=fwgt]

** choose which origin measure to use ***
renvars ho1 wo1 \ ho wo
drop if ho == .

*** figure 1 correlations ***
cor eduy_h eduy_w ho wo [aw=fwgt]
pcorr eduy_h eduy_w ho wo [aw=fwgt]
pcorr eduy_w ho wo eduy_h [aw=fwgt]
pcorr ho wo eduy_h eduy_w [aw=fwgt]

***** make 4 way tables *****
sum fwgt
replace fwgt = fwgt / r(mean) 


contract he we ho wo [fw=round(fwgt*10000,1)], zero freq(y0) // don't treat zero as missing //
replace y0 = y0/10000

foreach cat of numlist 1/7 {
	gen oh`cat' = (ho == wo & ho == `cat')
	lab var oh`cat' "homogamy: ho=wo=`cat'"
	}

foreach cat of numlist 1/7 {
	gen eh`cat' = (he == we & we == `cat')
	lab var eh`cat' "homogamy: he=we=`cat'"
	}

** differences
gen o_dif = ho - wo
gen e_dif = he - we
recode o_dif (min/-2=-1) (2/max=1), gen(o_dif3)
recode e_dif (min/-2=-1) (2/max=1), gen(e_dif3)

** distances
gen e_dis = abs(he-we)
gen o_dis = abs(ho-wo)

** parameters for quasi-symmetry models
gen eqs = he*10 + we if he <= we
replace eqs = we*10 + he if he > we
gen oqs = ho*10 + wo if ho <= wo
replace oqs = wo*10 + ho if ho > wo
table ho wo, c(mean oqs)

** define hypergamy as marriages where husband's education is higher than wife's
gen ehyper = e_dif > 0
gen ehomo = e_dif == 0
gen ehypo = e_dif < 0
gen ohyper = o_dif > 0
gen ohomo = o_dif == 0
gen ohypo = o_dif < 0

*gen his_ex = ehyper * ohypo
gen ehyperXohypo = ehyper * ohypo
*gen her_ex = -ehyper * ohyper
gen ehypoXohyper = -ehyper * ohyper
gen ehomoXohypo = ehomo * ohypo
gen ehomoXohyper = ehomo * ohyper

** exchange parameters
gen ex = e_dif*o_dif	
gen ex3 = e_dif3*o_dif3

** reference categories
char ho[omit] 4
char he[omit] 4
char wo[omit] 4
char we[omit] 4

lab define e_dif3 -1 "HE<WE" 0 "HE=WE" 1 "HE>WE"
lab values e_dif3 e_dif3
lab define o_dif3 -1 "HO<WO" 0 "HO=WO" 1 "HO>WO"
lab values o_dif3 o_dif3

** table differences **
table e_dif o_dif, c(sum y0) row col

**This is Table 2 in the paper
tab e_dif3 o_dif3 [fw=round(y0,1)], cell

tab he we [fw=round(y0,1)], row
tab ho wo [fw=round(y0,1)], row 



label variable ehypo "HE<WE"
label variable ehyper "HE>WE"
label variable ehomo "HE=WE"

** figure observed **
graph bar ehyper ehomo ehypo [fw=round(y0,1)], title("Panel A: Observed Proportions") bar(3, fcolor(gs10) lcolor(black) lwidth(vvthin)) bar(2, fcolor(gs12) lcolor(black) lwidth(vvthin)) bar(1, fcolor(gs14) lcolor(black) lwidth(vvthin)) over(o_dif3) stack blabel(bar, position(inside) format(%3.2f) ) legend(label(1 "HE>WE") label(2 "HE>WE") label(3 "HE<WE") row(1)) saving(observed, replace)

*****add a small number to zero frequencies *****
replace y0 = 0.005 if y0==0

** figure 2, observed distribution **
tab e_dif3 o_dif3 [fw=round(y0,1)], col

quietly xi: poisson y0 i.he*i.ho i.we*i.wo, nolog
predict y_m0

*Data for Figure 2, expected under random matching
tab e_dif3 o_dif3 [fw=round(y_m0,1)], col
/*
graph bar ehyper ehomo ehypo [fw=round(y_m0,1)], title("Panel B: Expected Proportions*") bar(3, fcolor(gs10) lcolor(black) lwidth(vvthin)) bar(2, fcolor(gs12) lcolor(black) lwidth(vvthin)) bar(1, fcolor(gs14) lcolor(black) lwidth(vvthin)) over(o_dif3) stack blabel(bar, position(inside) format(%3.2f) ) legend(label(1 "HE>WE") label(2 "HE>WE") label(3 "HE<WE") row(1)) saving(expected1, replace)
graph combine observed.gph expected1.gph, xsize(10) ysize(6) row(1) title("Figure 2: Couple's Relative Education Status by Relative Family Origin Status") note("Note: Panel B assumes random matching.")
graph export figure2_20160308_13.eps, fontface(Times) replace
*/

gen he4wo = ehyper * ohypo 
gen ho4we = ehypo * ohyper 
label variable he4wo "he4wo"
label variable ho4we "ho4we"

gen hEwO = he>ho & wo>=we
gen hOwE = he<=ho & we>wo

gen heGTo = he>ho
gen weGTo = we>wo
label define heGTo 1 "he>ho" 0 "he<=ho"
label define weGTo 1 "we>wo" 0 "we<=wo"
label values heGTo heGTo
label values weGTo weGTo

label variable hEwO "he>ho & wo>=we"
label variable hOwE "he<=ho & we>wo"

tab heGTo weGTo [fw=round(y0,1)]

*** model specification ***
*** models 1-6 for testing his and her exchanges without controlling for E-O association
local model1 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo" 
local model2 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo eh1-eh7 oh1-oh7" 
local model3 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.e_dis i.o_dis" 
local model4 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo eh1-eh7 oh1-oh7 i.e_dis i.o_dis" 
local model5 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.eqs i.oqs" 
local model6 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.we i.ho*i.wo" 

*** models 11-16 for testing his and her exchanges controlling for E-O association
local model11 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.ho i.we*i.wo" 
local model12 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.ho i.we*i.wo eh1-eh7 oh1-oh7" 
local model13 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.ho i.we*i.wo i.e_dis i.o_dis" 
local model14 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.ho i.we*i.wo eh1-eh7 oh1-oh7 i.e_dis i.o_dis" 
local model15 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.ho i.we*i.wo i.eqs i.oqs" 
local model16 "ehyperXohypo ehypoXohyper ehomo ehyper ohyper ohypo ehomoXohyper ehomoXohypo i.he*i.ho i.we*i.wo i.he*i.we i.ho*i.wo" 

*** model2 17-22 for testing hyp2
gen he4wo_hEwO = he4wo & hEwO
gen he4wo_hOwE = he4wo & hOwE //dropped due to colinearity//
gen he4wo_ = he4wo & (hOwE==0) & (hEwO==0) 

gen ho4we_hEwO = ho4we & hEwO //dropped due to colinearity//
gen ho4we_hOwE = ho4we & hOwE
gen ho4we_ = ho4we & (hOwE==0) & (hEwO==0) 

local model17 "he4wo_ he4wo_hEwO he4wo_hOwE ho4we_ ho4we_hEwO ho4we_hOwE i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo"
local model18 "he4wo_ he4wo_hEwO he4wo_hOwE ho4we_ ho4we_hEwO ho4we_hOwE i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo eh1-eh7 oh1-oh7 "
local model19 "he4wo_ he4wo_hEwO he4wo_hOwE ho4we_ ho4we_hEwO ho4we_hOwE i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo i.e_dis i.o_dis"
local model20 "he4wo_ he4wo_hEwO he4wo_hOwE ho4we_ ho4we_hEwO ho4we_hOwE i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo eh1-eh7 oh1-oh7 i.e_dis i.o_dis"
local model21 "he4wo_ he4wo_hEwO he4wo_hOwE ho4we_ ho4we_hEwO ho4we_hOwE i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo i.eqs i.oqs"
local model22 "he4wo_ he4wo_hEwO he4wo_hOwE ho4we_ ho4we_hEwO ho4we_hOwE i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo i.he*i.we i.ho*i.wo"

*** testing significance of he4wo_ vs he4wo_hEwO and ho4we_ vs ho4we_hOwE

local model23 "i.he4wo*hEwO i.ho4we*hEwO i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.he4wo*hOwE i.ho4we*hOwE i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo"
local model24 "i.he4wo*hEwO i.ho4we*hEwO i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.he4wo*hOwE i.ho4we*hOwE i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo eh1-eh7 oh1-oh7 "
local model25 "i.he4wo*hEwO i.ho4we*hEwO i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.he4wo*hOwE i.ho4we*hOwE i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo i.e_dis i.o_dis"
local model26 "i.he4wo*hEwO i.ho4we*hEwO i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.he4wo*hOwE i.ho4we*hOwE i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo eh1-eh7 oh1-oh7 i.e_dis i.o_dis"
local model27 "i.he4wo*hEwO i.ho4we*hEwO i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.he4wo*hOwE i.ho4we*hOwE i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo i.eqs i.oqs"
local model28 "i.he4wo*hEwO i.ho4we*hEwO i.ehomo*hEwO i.ehyper*hEwO i.ohyper*hEwO i.ohypo*hEwO i.ehomoXohypo*hEwO i.ehomoXohyper*hEwO i.he4wo*hOwE i.ho4we*hOwE i.ehomo*hOwE i.ehyper*hOwE i.ohyper*hOwE i.ohypo*hOwE i.ehomoXohypo*hOwE i.ehomoXohyper*hOwE i.he*i.ho i.we*i.wo i.he*i.we i.ho*i.wo"

/*estat ic uses Akaikes and Schwarzs Bayesian information criteria
where N is the total sample size 6273
AIC = ?2 ? ln(likelihood) + 2 ? k
BIC = ?2 ? ln(likelihood) + ln(N ) ? k
*/

xi: poisson y0 `model1', nolog
foreach i of numlist 1/6 17/28 { 
	display " "
	display "**********model`i': `model`i''***********"
	xi: poisson y0 `model`i'', nolog
	display "******Test goodness of fit of Poisson model*****"
    estat gof
	display "******Test whether sex diff (HE for WO versus WE for HO) is stat sig*****"
	*test ehyperXohypo = ehypoXohyper 
	estimates store m`i', title(Model `i')
	predict y`i'
	estat ic, n(`nobs')
	matrix m`i' = r(S)
	preserve
	matrix eb=e(b)
	svmat eb, names( matcol )
	keep in 1
	gen model = `i'
	tempfile m`i'
	save `m`i''
	restore
	}

xi: poisson y0 `model1', nolog
foreach i of numlist 11/16 { 
	display " "
	display "**********model`i': `model`i''***********"
	xi: poisson y0 `model`i'', nolog
	display "******Test goodness of fit of Poisson model*****"
    estat gof
	display "******Test whether sex diff (HE for WO versus WE for HO) is stat sig*****"
	test ehyperXohypo = ehypoXohyper 
	estimates store m`i', title(Model `i')
	predict y`i'
	estat ic, n(`nobs')
	matrix m`i' = r(S)
	preserve
	matrix eb=e(b)
	svmat eb, names( matcol )
	keep in 1
	gen model = `i'
	tempfile m`i'
	save `m`i''
	restore
	}         
*package name:  estout.pkg
estout m1 m2 m3 m4 m5 m6 using out20160320_13a.txt, replace eform cells(b(star fmt(3)) se(par fmt(2))) style(tab) legend label stats(N, fmt(%9.0g) ) 
estout m11 m12 m13 m14 m15 m16 using out20160320_13b.txt, replace eform cells(b(star fmt(3)) se(par fmt(2))) style(tab) legend label stats(N, fmt(%9.0g) ) 
estout m17 m18 m19 m20 m21 m22 using out20160320_13c.txt, replace eform cells(b(star fmt(3)) se(par fmt(2))) style(tab) legend label stats(N, fmt(%9.0g) ) 
estout m23 m24 m25 m26 m27 m28 using out20160320_13d.txt, replace eform cells(b(star fmt(3)) p(par fmt(3))) style(tab) legend label stats(N, fmt(%9.0g) ) 

matrix fitstats = m1
	foreach i of numlist 2/6 11/28 {
	matrix fitstats = fitstats\m`i'
}

matrix list fitstats


*crs 05/29/15: Negative binomial versions of the model, suggested by AJS reviewer A

*Test for overdispersion (following http://www.ats.ucla.edu/stat/stata/faq/count.htm and 
*http://www.stata.com/manuals13/rpoissonpostestimation.pdf#rpoissonpostestimation)

**Step 1 - is mean of count variable equal to variance? Answer: No the variance is much larger than the mean
summarize y0, detail

**Step 2 - use the poisgof command, which tests the poisson goodness-of-fit. Adding this to
**         the code above
**		   Answer: Looks like the data are Poisson distributed (cannot reject the null that
** 		   they're not) in models 3-6. So it makes sense that the results are the same
**		   using Poisson reg and negative binomial reg.
    

*renaming so that variables from matrix command will be different than above
gen y0nb = y0

xi: nbreg y0nb `model1', nolog
foreach i of numlist 2/6 11/16 { 
	display " "
	display "**********model`i': `model`i''***********"
	qui xi: nbreg y0nb `model`i'', nolog
	display "******Test whether sex diff (HE for WO versus WE for HO) is stat sig*****"
	test ehyperXohypo = ehypoXohyper
	estimates store m_nbreg`i', title(Model `i')
	predict y_nbreg`i'
	qui estat ic
	matrix m_nbreg`i' = r(S)
/*	preserve
	 matrix eb_nbreg=e(b)
	 svmat eb_nbreg, names( matcol )
	 keep in 1
	 gen model = `i'
	 tempfile m`i'
	 save `m`i''
	restore  */
	}

/*
matrix fitstats_nbreg = m_nbreg1
	foreach i of numlist 2/6 11/16 {
	matrix fitstats_nbreg = fitstats_nbreg\m_nbreg`i'
}

matrix list fitstats_nbreg	
*/
	
*package name:  estout.pkg
estout m_nbreg11 m_nbreg12 m_nbreg13 m_nbreg14 m_nbreg15 m_nbreg16 using out_nbreg_20160320.txt, replace eform cells(b(star fmt(3)) se(par fmt(2))) style(tab) legend label stats(N, fmt(%9.0g) ) 



log close
exit

